@@ -4,6 +4,8 @@ generating version 6 and 7 UUIDs as specified in
 https://github.com/uuid6/uuid6-ietf-draft.
 """
 
+import secrets
+import time
 from uuid import UUID
 
 
@@ -43,7 +45,7 @@ class DraftUUID(UUID):
                 | (self.time_hi_version & 0x0FFF)
             )
         if self.version == 7:
-            return self.unixts * 10 ** 9 + self.subsec
+            return self.unixts * 10 ** 9 + _subsec_decode(self.subsec)
         return super().time
 
     @property
@@ -51,10 +53,12 @@ class DraftUUID(UUID):
         return self.time_low << 4 | self.time_mid >> 12
 
 
-def _getrandbits(k: int) -> int:
-    import secrets
+def _subsec_decode(value: int) -> int:
+    return -(-value * 10 ** 9 // 2 ** 30)
 
-    return secrets.randbits(k)
+
+def _subsec_encode(value: int) -> int:
+    return value * 2 ** 30 // 10 ** 9
 
 
 _last_v6_timestamp = None
@@ -67,7 +71,6 @@ def uuid6(clock_seq: int = None) -> UUID:
     otherwise a random 14-bit sequence number is chosen."""
 
     global _last_v6_timestamp
-    import time
 
     nanoseconds = time.time_ns()
     # 0x01b21dd213814000 is the number of 100-ns intervals between the
@@ -77,8 +80,8 @@ def uuid6(clock_seq: int = None) -> UUID:
         timestamp = _last_v6_timestamp + 1
     _last_v6_timestamp = timestamp
     if clock_seq is None:
-        clock_seq = _getrandbits(14)  # instead of stable storage
-    node = _getrandbits(48)
+        clock_seq = secrets.randbits(14)  # instead of stable storage
+    node = secrets.randbits(48)
     time_high_and_time_mid = (timestamp >> 12) & 0xFFFFFFFFFFFF
     time_low_and_version = timestamp & 0x0FFF
     uuid_int = time_high_and_time_mid << 80
@@ -98,17 +101,17 @@ def uuid7() -> UUID:
     used during encoding in order to function correctly."""
 
     global _last_v7_timestamp
-    import time
 
     nanoseconds = time.time_ns()
     if _last_v7_timestamp is not None and nanoseconds <= _last_v7_timestamp:
         nanoseconds = _last_v7_timestamp + 1
     _last_v7_timestamp = nanoseconds
     timestamp_s, timestamp_ns = divmod(nanoseconds, 10 ** 9)
-    subsec_a = timestamp_ns >> 18
-    subsec_b = (timestamp_ns >> 6) & 0x0FFF
-    subsec_c = timestamp_ns & 0x3F
-    rand = _getrandbits(56)
+    subsec = _subsec_encode(timestamp_ns)
+    subsec_a = subsec >> 18
+    subsec_b = (subsec >> 6) & 0x0FFF
+    subsec_c = subsec & 0x3F
+    rand = secrets.randbits(56)
     uuid_int = (timestamp_s & 0x0FFFFFFFFF) << 92
     uuid_int |= subsec_a << 80
     uuid_int |= subsec_b << 64
